/*DOC************************************************************************
		 
File Name: testb.c

Description: Test suite for VCR Buttons.

*DOC************************************************************************/

#define STRICT 

#define NOMINMAX
#define NOCOMM
#define NOSYSMETRICS
#define NOICONS
#define NOKEYSTATES
#define NOSYSCOMMANDS
#define NOOEMRESOURCE
#define NOATOM
#define NOCLIPBOARD
#define NOSOUND
#define NOTEXTMETRIC
#define NOWH
#define NOKANJI
#define NOHELP
#define NOPROFILER
#define NODEFERWINDOWPOS

#include <windows.h>
#include "testb.h"

/*
** Defines for custom VCR button
*/

#include "vcrbut.h"

HANDLE hInst;
HWND hWndMain;
 
LPSTR class_name = "Test_Button_App";

/*****************************************************************************

Function Name: DlgProcTest
Purpose:	 Test enhanced button dialog

*****************************************************************************/
BOOL FAR PASCAL DlgProcTest(HWND hDlg, unsigned message, WPARAM wParam, LPARAM lParam)
{								
	int state;

	switch (message)
	{
		case WM_INITDIALOG:
		
			/*
			** Set a wide border on the button with the wide border label
			*/
		
			SendMessage( GetDlgItem( hDlg, ID_BN_TEST4 ), BM_SETBORDER, 5, 0L );

			/*
			** Select the first VCR button in an auto VCR group
			*/
			
			CheckDlgButton( hDlg, ID_BN_TEST1, TRUE );
			SetFocus( GetDlgItem( hDlg, ID_BN_TEST1 ));
			return( FALSE );
				
		case WM_DESTROY:
		
			break;

	
		case WM_COMMAND:

			switch( wParam )
			{
				case ID_BN_TEST4:
				case ID_BN_TEST5:
				case ID_BN_TEST6:
				
					if ( HIWORD( lParam ) == BN_CLICKED )
					{
						state = IsDlgButtonChecked( hDlg, wParam );
						SendMessage( (HWND) LOWORD( lParam ), BM_SETCHECK, !state, 0L );
					}
					break;
				
				case IDCANCEL:
				case IDOK:

					EndDialog( hDlg, FALSE );
					return( TRUE );
			}
			
		default :
			
			break;

		}

	return( FALSE );
}

/*************************************************************************

Function Name: WndProcTest

Purpose: Main window proc

*************************************************************************/
long FAR PASCAL __export WndProcTest( HWND hWnd, unsigned message, WPARAM wParam, LPARAM lParam)
{
	
	switch( message ) 
	{

		case WM_COMMAND:
	
			switch( wParam )		 
			{

				case IDM_TEST:
			
					DialogBox( hInst, "BUTTON_TEST", hWnd, DlgProcTest );
					break;

				case IDM_EXIT:
					
					DestroyWindow( hWnd );
					break;
			}
			break;

		case WM_DESTROY:

			PostQuitMessage(0);
			break;

		default:	
			
			break;
	}		

	return( DefWindowProc( hWnd, message, wParam, lParam ));
}

/**************************************************************************

Function Name: TestInit

Purpose: This function performs the application initialization

***************************************************************************/
int TestInit( HANDLE hInstance, HANDLE hPrevInstance, LPSTR lpCmdLine, int nCmdShow ) 
{
	WNDCLASS	WndClass;

	hInst = hInstance;

	/*	
	** Create a window class for application
	*/
	
	WndClass.style 			= NULL;
	WndClass.lpfnWndProc		= WndProcTest;		 
	WndClass.hInstance		= hInst;
	WndClass.hIcon				= (HANDLE) NULL;
	WndClass.hCursor			= LoadCursor( NULL, IDC_ARROW );
	WndClass.hbrBackground	= (HBRUSH) COLOR_WINDOW + 1;
 	WndClass.cbClsExtra		= 0;
	WndClass.cbWndExtra		= 0;
	WndClass.lpszMenuName	= (LPSTR) "TestMenu";
	WndClass.lpszClassName	= class_name;

	if ( RegisterClass( &WndClass ) == 0 )
			return( FALSE );

	/*
	** Create a Top level Window
	*/

	hWndMain = CreateWindow( class_name, 
				  "Button Test Application",
	  				WS_OVERLAPPEDWINDOW,
					CW_USEDEFAULT,	  
					CW_USEDEFAULT,	  
					CW_USEDEFAULT,	 
					CW_USEDEFAULT,	 
					NULL,			  
					NULL,			  
					hInstance,	  
					NULL );		  

	if ( ! hWndMain )
		return( FALSE );

	ShowWindow( hWndMain, nCmdShow );
	UpdateWindow( hWndMain );			

	return( TRUE );
}

/*************************************************************************

Function Name: WinMain
	Purpose: Windows Main Entry Point.
  
**************************************************************************/
int PASCAL WinMain( HINSTANCE hInstance, HINSTANCE hPrevInstance, 
 					 LPSTR lpCmdLine,  int nCmdShow) 
{
	MSG msg;					 // message


	hInst = hInstance;		/* Saves the current instance				 */

	if ( ! TestInit( hInstance, hPrevInstance, lpCmdLine, nCmdShow ) )
		return( NULL );

	while( GetMessage( &msg, NULL, NULL, NULL )) 
	{
		TranslateMessage( &msg );
		DispatchMessage( &msg ); 
	}
	return( msg.wParam );	  
}

